pub struct OtelGuard { /* private fields */ }Expand description
A guard that holds the tracer provider, meter provider, and logger provider and ensures proper cleanup.
The guard has unique ownership of provider shutdown and cannot be cloned.
ⓘ
use otel_init::OtelGuard;
let guard = OtelGuard::new(None, None, None);
let _duplicate = guard.clone();Implementations
Sourceimpl OtelGuard
impl OtelGuard
Sourcepub fn new(
tracer_provider: Option<SdkTracerProvider>,
meter_provider: Option<SdkMeterProvider>,
logger_provider: Option<SdkLoggerProvider>,
) -> Self
pub fn new( tracer_provider: Option<SdkTracerProvider>, meter_provider: Option<SdkMeterProvider>, logger_provider: Option<SdkLoggerProvider>, ) -> Self
Create a new guard with the given providers
pub fn with_tracer_provider(self, tracer_provider: SdkTracerProvider) -> Self
pub fn with_meter_provider(self, meter_provider: SdkMeterProvider) -> Self
pub fn with_logger_provider(self, logger_provider: SdkLoggerProvider) -> Self